@@ -1,7 +1,7 @@
 // qsampler.cpp
 //
 /****************************************************************************
-   Copyright (C) 2004-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2004-2021, rncbc aka Rui Nuno Capela. All rights reserved.
    Copyright (C) 2007,2008,2015,2019 Christian Schoenebeck
 
    This program is free software; you can redistribute it and/or
@@ -111,7 +111,11 @@ qsamplerApplication::qsamplerApplication ( int& argc, char **argv )
 		// Try own Qt translation...
 		m_pQtTranslator = new QTranslator(this);
 		QString sLocName = "qt_" + loc.name();
+	#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+		QString sLocPath = QLibraryInfo::path(QLibraryInfo::TranslationsPath);
+	#else
 		QString sLocPath = QLibraryInfo::location(QLibraryInfo::TranslationsPath);
+	#endif
 		if (m_pQtTranslator->load(sLocName, sLocPath)) {
 			QApplication::installTranslator(m_pQtTranslator);
 		} else {
@@ -122,7 +126,7 @@ qsamplerApplication::qsamplerApplication ( int& argc, char **argv )
 			} else {
 		#endif
 			delete m_pQtTranslator;
-			m_pQtTranslator = 0;
+			m_pQtTranslator = nullptr;
 		#ifdef CONFIG_DEBUG
 			qWarning("Warning: no translation found for '%s' locale: %s/%s.qm",
 				loc.name().toUtf8().constData(),
@@ -148,7 +152,7 @@ qsamplerApplication::qsamplerApplication ( int& argc, char **argv )
 				QApplication::installTranslator(m_pMyTranslator);
 			} else {
 				delete m_pMyTranslator;
-				m_pMyTranslator = 0;
+				m_pMyTranslator = nullptr;
 			#ifdef CONFIG_DEBUG
 				qWarning("Warning: no translation found for '%s' locale: %s/%s.qm",
 					loc.name().toUtf8().constData(),
@@ -484,7 +488,9 @@ int main ( int argc, char **argv )
 #endif
 #endif
 #if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
+#if QT_VERSION <  QT_VERSION_CHECK(6, 0, 0)
 	QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#endif
 #endif
 	qsamplerApplication app(argc, argv);
 
